@@ -251,7 +251,13 @@ import '{package}.pbgrpc.dart';
     for msg in messages:
         if msg.has_methods:
             content += f'    registerClient({msg.name}MethodsClient(channel, interceptors: [AuthInterceptor(tokenProvider: tokenProvider, realmProvider: realmProvider)]));\n'
-    content += '}\n'
+    content += '}\n\n'
+
+    content += 'final constructors = {\n'
+    for msg in messages:
+        content += f'    {msg.name}: () => {msg.name}(),\n'
+        content += f'    PbList<{msg.name}>: () => {msg.name}(),\n'
+    content += '};\n'
 
     # registerRpcClients(ClientChannelBase channel, String token) {
     # registerClient(EmployeeMethodsClient(channel, interceptors: [AuthInterceptor(token)]));
