@@ -126,11 +126,8 @@ class GenericServicer:
                 mongo_settings = settings.get('mongodb', {})
                 db = Db(
                     mongo_settings.get('host', 'localhost'),
-                    mongo_settings.get('port', 27017),
-                    context.realm,
-                    username=mongo_settings.get('username'),
-                    password=mongo_settings.get('password')
-                    )
+                    mongo_settings.get('port', 27017), 
+                    context.realm)
                 
                 # First if: Uniary call or Client-Side-Streaming
                 if isinstance(request, grpc._server._RequestIterator): # streaming call
